@@ -75,7 +75,7 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
 
   def self.get_neutron_credentials
     #needed keys for authentication
-    auth_keys = ['auth_uri', 'project_name', 'username', 'password']
+    auth_keys = ['auth_url', 'project_name', 'username', 'password']
     conf = neutron_conf
     if conf and conf['keystone_authtoken'] and
         auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
@@ -104,7 +104,7 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
 
   def self.get_auth_endpoint
     q = neutron_credentials
-    "#{q['auth_uri']}"
+    "#{q['auth_url']}"
   end
 
   def self.auth_endpoint
@@ -235,8 +235,8 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
     if ! instance
       instance = Puppet::Type.type(instance_type).instances.find do |i|
         # We need to check against the Default domain name because of
-        # https://review.openstack.org/#/c/226919/ which changed the naming
-        # format for the tenant to include ::<Domain name>. This should be
+        # https://review.opendev.org/#/c/226919/ which changed the naming
+        # format for the tenant to include <Domain name>. This should be
         # removed when we drop the resource without a domain name.
         # TODO(aschultz): remove ::domain lookup as part of M-cycle
         i.provider.name == name || i.provider.name == "#{name}::#{domain}"
